import type { CSSProperties } from 'react'
import type { TextStyle } from 'react-native'
import transform from 'css-to-react-native'

export interface HighlighterStyleSheet {
  [key: string]: TextStyle
}
export type ReactStyle = Record<string, CSSProperties>

const ALLOWED_STYLE_PROPERTIES: Record<string, boolean> = {
  color: true,
  background: true,
  backgroundColor: true,
  fontWeight: true,
  fontStyle: true,
}

export function getRNStylesFromShikiStyle(shikiStyle: ReactStyle): HighlighterStyleSheet {
  return Object.fromEntries(
    Object.entries(shikiStyle)
      .map(([className, style]) => {
        // Filter the styles based on allowed properties
        const filteredStyle = Object.fromEntries(
          Object.entries(style).filter(([property]) => ALLOWED_STYLE_PROPERTIES[property]),
        )

        // Convert the filtered style to React Native style
        const rnStyle: TextStyle = transform(Object.entries(filteredStyle)) as TextStyle

        return [className, rnStyle] // Return the class name and the converted style
      }),
  )
}
